;; -*-mode: ahk; coding:utf-8-dos-*-"
;; last updated: 2012-03-31 04:07:43

;;; DvorakJ manager
;;; AutoHotkey_L <http://www.autohotkey.net/~Lexikos/AutoHotkey_L/>
;;; blechmusik <http://blechmusik.xii.jp/>



;;; ============================================================================
;;; ---------------- 各種設定
;;; ============================================================================

;;; Performance
;;; http://www.autohotkey.com/docs/misc/Performance.htm

#NoEnv
#SingleInstance FORCE
#WinActivateForce
#persistent
SetWorkingDir %A_ScriptDir%


;;; AutoHotkey_L - #MenuMaskKey
;;; http://www.autohotkey.net/~Lexikos/AutoHotkey_L/docs/commands/_MenuMaskKey.htm
#MenuMaskKey vk07

;;; #MaxThreadsBuffer - AutoHotkeyJp
;;; http://sites.google.com/site/autohotkeyjp/reference/commands/-MaxThreadsBuffer
;;; #MaxThreadsBuffer On




#UseHook
#InstallKeybdHook
#InstallMouseHook


;;; AutoHotkeyJp: Process
;;; http://sites.google.com/site/autohotkeyjp/reference/commands/Process
Process, Priority, , High


;;; AutoHotkeyJp: SetBatchLines
;;; http://sites.google.com/site/autohotkeyjp/reference/commands/SetBatchLines
SetBatchLines, -1
;;; スクリプトの実行履歴を保存しない
ListLines Off

;;; sendmode を input に設定しない
;;; 非常に素早く何度も打鍵すると、キーフックが効かなくなることがあるから
;;; たとえば、Dvorak 配列の [H] を押したままにすると、元のキーである QWERTY 配列の [J] がときたま出力されてしまう
;;; sendmode input

; SetKeyDelay, 0
; SetControlDelay, 0
; SetMouseDelay, 0
; SetWinDelay, 0

#HotkeyInterval 1000
#MaxHotkeysPerInterval 100



DetectHiddenWindows, Off
DetectHiddenText, Off


#include %A_ScriptDir%

;; タイマー割り込みを禁止する
Thread, NoTimers

;;; ==============================
;;; ==============================
;;; ==============================
;;; 設定ファイルを指定する
;;; z:\dvorakj\apps\dvorakj_manager.ahk というパスから、z:\dvorakj を取り出す
;;; つまり、このファイルの絶対パスから "\apps\dvorakj_manager.ahk" を取り除く
SplitPath, A_ScriptDir, name, dvorakj_dir


setting_file_path_folder := dvorakj_dir . to_windows_path("/user/")
setting_file_path_filename := "setting.ini"
version_ini := dvorakj_dir . to_windows_path("/data/version.ini")

;;; ==============================
;;; ==============================
;;; ==============================

;; 設定画面の処理とのやりとりに使うファイル
dvorakj_info_ini := A_Temp . to_windows_path("/dvorakj_info.ini")
;; そのファイルの更新時刻を取得する
dvorakj_info_ini_mtime := get_file_mtime( dvorakj_info_ini )
;; DvorakJ の版の情報を取得する
dvorakj_current_version := read_version_setting(version_ini)

;; そのファイルを新たに作成する
;delete_and_append_file(dvorakj_info_ini)

this_key := ""



;;; ============================================================================
;;; ---------------- アイコンを指定する
;;; ============================================================================

;;; ユーザーが指定するアイコンを使用する
#Include ..\src\GUI\icon.ahk


;;; ============================================================================
;;; ---------------- ini ファイルで管理する項目
;;; ============================================================================

;;; ini ファイルの指定
ini_file := setting_file_path_folder . setting_file_path_filename
IfExist, %ini_file%
    ini_file_exists := True


#Include ..\src\init\io_dvorakj_ini.ahk
#Include ..\src\init\read_setting.ahk

read_general_setting()


;;; ============================================================================
;;; ---------------- キーボード配列の設定を設定ファイルから読み込む
;;; ============================================================================

;;; ============================================================================
;;; ---------------- GUI
;;; ============================================================================



;;; 設定ウィンドウ上で設定できるもの
#Include ..\src\GUI\overall_framework.ahk
;;; メニューバー中のメニューとタスクトレイのメニュー
#Include ..\src\GUI\menu.ahk
;;; jump list
#Include ..\src\GUI\jump_list.ahk
;;; 設定ウィンドウ
#Include ..\src\GUI\tab1-4.ahk
#Include ..\src\GUI\tab5.ahk
#Include ..\src\GUI\tab6.ahk
#Include ..\src\GUI\tab7-14.ahk
#Include ..\src\GUI\tab15.ahk
#Include ..\src\GUI\tab16.ahk
#Include ..\src\GUI\tab17.ahk
#Include ..\src\GUI\tab18.ahk

;;; ステータスバー
#Include ..\src\GUI\change_text_within_status_bar.ahk
;;; DvorakJ の機能の有効にしたり無効にしたりする
#Include ..\src\GUI\toggle_Layout.ahk

;;; ============================================================================
;;; ---------------- 設定ウィンドウを表示する
;;; ============================================================================

;;; 設定ウィンドウを表示
#Include ..\src\GUI\show.ahk

;;; 設定ウィンドウの画面上の位置を取得出来るようにメッセージを送る
OnMessage(0x232, "WM_SIZEMOVE")


;;; ============================================================================
;;; ---------------- return
;;; ============================================================================

if ( ini_file_exists ) {
    Progress, Off
}

SetTimer, watch_dvorakj_info_ini_update, 100

return


; dvorakj_info_ini の更新時刻を定期的に監視する
watch_dvorakj_info_ini_update:
	
	if (dvorakj_info_mtime != read_value_from_dvorakj_info_ini("itself", "dvorakj_info_mtime"))
	{
		dvorakj_info_mtime := read_value_from_dvorakj_info_ini("itself", "dvorakj_info_mtime")

		;; 終了
		if ( read_value_from_dvorakj_info_ini("state", "close")) {
			ExitApp
		}

		;; 本体の処理が停止中かどうかを調べる
		bSuspended := read_value_from_dvorakj_info_ini("state", "bSuspended")

		;; GUI 内の項目の表示を切り替える
		GUI_Toggle(bSuspended)
	}
return


;;; ============================================================================
;;; ---------------- GUI
;;; ============================================================================


#Include ..\src\GUI\subroutine_for_GUI.ahk
;;; キーボード配列の設定ファイルを選択するウィンドウ
#Include ..\src\GUI\ChooseSettingFile.ahk

;;; ステータスバーを定期的に更新する
#Include ..\src\GUI\update_status_bar.ahk

;;; ============================================================================
;;; ---------------- lib
;;; ============================================================================

;;; 配列を操作する
#Include ..\src\lib\Array.ahk

;;; コメントアウトを除去する
#Include ..\src\lib\remove_comment_out.ahk

;;; skkime 用の設定
#Include ..\src\lib\SKKIME.ahk


#Include ..\src\lib\ext_func_calc.ahk
#Include ..\src\lib\ext_func_control.ahk
#Include ..\src\lib\ext_func_file.ahk
#Include ..\src\lib\ext_func_flow.ahk
#Include ..\src\lib\ext_func_gui.ahk
#Include ..\src\lib\ext_func_ini.ahk
#Include ..\src\lib\ext_func_key.ahk
#Include ..\src\lib\ext_func_memdll.ahk
#Include ..\src\lib\ext_func_mouse.ahk
#Include ..\src\lib\ext_func_object.ahk
#Include ..\src\lib\ext_func_shell.ahk
#Include ..\src\lib\ext_func_str.ahk

;; jump list
#Include ..\src\lib\JumpList.ahk

;;; テキストをファイルから抜き出す get_text を使用する
#Include ..\src\lib\get_text.ahk



;;; ============================================================================
;;; ---------------- system
;;; ============================================================================

;;; 設定ファイルから設定ウィンドウの表示位置の設定を読み込む
#Include ..\src\system\GetWinPos.ahk
;;; ファイル名を取得する
#Include ..\src\system\GetFileName.ahk
;;; フォントサイズを取得する
#Include ..\src\system\GetDPI.ahk
;;; Caps Lock の値を定期的に調べる
#Include ..\src\system\CapsLockState.ahk
;;; 実際に押し下げている修飾キーを取得する
#Include ..\src\system\get_modified_keys_pressed_down.ahk

